@@ -1,4 +1,4 @@
-from nustudio.htm import maxStoredSteps
+from nustudio.htm import maxPreviousSteps
 from nustudio.ui import Global
 
 class Bit:
@@ -31,8 +31,9 @@ class Bit:
 		"""Position on Y axis"""
 
 		# States of this element
-		self.isActive = [False] * maxStoredSteps
-		self.isPredicted = [False] * maxStoredSteps
+		self.isActive = [False] * maxPreviousSteps
+		self.isPredicted = [False] * maxPreviousSteps
+		self.isFalselyPredicted = [False] * maxPreviousSteps
 
 		#region Statistics properties
 
@@ -60,11 +61,13 @@ class Bit:
 		"""
 
 		# Update states machine by remove the first element and add a new element in the end
-		if len(self.isActive) > maxStoredSteps:
+		if len(self.isActive) > maxPreviousSteps:
 			self.isActive.remove(self.isActive[0])
 			self.isPredicted.remove(self.isPredicted[0])
+			self.isFalselyPredicted.remove(self.isFalselyPredicted[0])
 		self.isActive.append(False)
 		self.isPredicted.append(False)
+		self.isFalselyPredicted.append(False)
 
 	def calculateStatistics(self):
 		"""
@@ -72,9 +75,9 @@ class Bit:
 		"""
 
 		# Calculate statistics
-		if self.isActive[maxStoredSteps - 1]:
+		if self.isActive[maxPreviousSteps - 1]:
 			self.statsActivationCount += 1
-		if self.isPredicted[maxStoredSteps - 1]:
+		if self.isPredicted[maxPreviousSteps - 1]:
 			self.statsPreditionCount += 1
 		if Global.currStep > 0:
 			self.statsActivationRate = self.statsActivationCount / float(Global.currStep)
