@@ -1,4 +1,4 @@
-from nustudio.htm import maxStoredSteps
+from nustudio.htm import maxPreviousSteps
 from nustudio.ui import Global
 
 class Synapse:
@@ -24,13 +24,14 @@ class Synapse:
 		self.inputElem = None
 		"""An input element is a cell in case of the source be a column or then a bit in case of the source be a sensor"""
 
-		self.permanence = [0.] * maxStoredSteps
+		self.permanence = [0.] * maxPreviousSteps
 		"""Permanence of this synapse."""
 
 		# States of this element
-		self.isConnected = [False] * maxStoredSteps
-		self.isPredicted = [False] * maxStoredSteps
-		self.isRemoved = [False] * maxStoredSteps
+		self.isConnected = [False] * maxPreviousSteps
+		self.isPredicted = [False] * maxPreviousSteps
+		self.isFalselyPredicted = [False] * maxPreviousSteps
+		self.isRemoved = [False] * maxPreviousSteps
 
 		#region Statistics properties
 
@@ -61,14 +62,16 @@ class Synapse:
 		"""
 
 		# Update states machine by remove the first element and add a new element in the end
-		if len(self.isConnected) > maxStoredSteps:
+		if len(self.isConnected) > maxPreviousSteps:
 			self.permanence.remove(self.permanence[0])
 			self.isConnected.remove(self.isConnected[0])
 			self.isPredicted.remove(self.isPredicted[0])
+			self.isFalselyPredicted.remove(self.isFalselyPredicted[0])
 			self.isRemoved.remove(self.isRemoved[0])
 		self.permanence.append(0.)
 		self.isConnected.append(False)
 		self.isPredicted.append(False)
+		self.isFalselyPredicted.append(False)
 		self.isRemoved.append(False)
 
 	def calculateStatistics(self):
@@ -77,9 +80,9 @@ class Synapse:
 		"""
 
 		# Calculate statistics
-		if self.isConnected[maxStoredSteps - 1]:
+		if self.isConnected[maxPreviousSteps - 1]:
 			self.statsConnectionCount += 1
-		if self.isPredicted[maxStoredSteps - 1]:
+		if self.isPredicted[maxPreviousSteps - 1]:
 			self.statsPreditionCount += 1
 		if Global.currStep > 0:
 			self.statsConnectionRate = self.statsConnectionCount / float(Global.currStep)
