@@ -1,7 +1,9 @@
 ﻿from PyQt4 import Qt, QtGui, QtCore
 from nustudio import ArrayTableModel
 from nustudio.ui import Global
+from nustudio.htm import maxPreviousSteps, maxFutureSteps
 from nustudio.htm.node import NodeType, Node
+from nustudio.htm.node_sensor import InputFormat, InputRawDataType, InputRawDataType, PredictionsMethod
 
 class NodeInformationForm(QtGui.QWidget):
 
@@ -46,6 +48,34 @@ class NodeInformationForm(QtGui.QWidget):
 		self.textBoxSensorName.setEnabled(False)
 		self.textBoxSensorName.setAlignment(QtCore.Qt.AlignLeft)
 
+		# labelSensorPrecisionRate
+		self.labelSensorPrecisionRate = QtGui.QLabel()
+		self.labelSensorPrecisionRate.setText("Precision Rate (%)")
+		self.labelSensorPrecisionRate.setAlignment(QtCore.Qt.AlignRight)
+
+		# textBoxSensorPrecisionRate
+		self.textBoxSensorPrecisionRate = QtGui.QLineEdit()
+		self.textBoxSensorPrecisionRate.setEnabled(False)
+		self.textBoxSensorPrecisionRate.setAlignment(QtCore.Qt.AlignRight)
+
+		# tabPageSensor1Layout
+		tabPageSensor1Layout = QtGui.QGridLayout()
+		tabPageSensor1Layout.addWidget(self.labelSensorName, 0, 0)
+		tabPageSensor1Layout.addWidget(self.textBoxSensorName, 0, 1)
+		tabPageSensor1Layout.addWidget(self.labelSensorPrecisionRate, 1, 0)
+		tabPageSensor1Layout.addWidget(self.textBoxSensorPrecisionRate, 1, 1)
+		tabPageSensor1Layout.setRowStretch(2, 100)
+
+		# checkBoxEnableClassificationLearning
+		self.checkBoxEnableClassificationLearning = QtGui.QCheckBox()
+		self.checkBoxEnableClassificationLearning.setText("Enable Classification Learning")
+		self.checkBoxEnableClassificationLearning.toggled.connect(self.__checkBoxEnableClassificationLearning_Toggled)
+
+		# checkBoxEnableClassificationInference
+		self.checkBoxEnableClassificationInference = QtGui.QCheckBox()
+		self.checkBoxEnableClassificationInference.setText("Enable Classification Inference")
+		self.checkBoxEnableClassificationInference.toggled.connect(self.__checkBoxEnableClassificationInference_Toggled)
+
 		# labelCurrentValue
 		self.labelCurrentValue = QtGui.QLabel()
 		self.labelCurrentValue.setText("Current Value")
@@ -58,28 +88,56 @@ class NodeInformationForm(QtGui.QWidget):
 
 		# labelPredictedValue
 		self.labelPredictedValue = QtGui.QLabel()
-		self.labelPredictedValue.setText("Predicted Value")
+		self.labelPredictedValue.setText("Predicted Values")
 		self.labelPredictedValue.setAlignment(QtCore.Qt.AlignRight)
 
-		# textBoxPredictedValue
-		self.textBoxPredictedValue = QtGui.QLineEdit()
-		self.textBoxPredictedValue.setEnabled(False)
-		self.textBoxPredictedValue.setAlignment(QtCore.Qt.AlignRight)
+		# dataGridPredictedValues
+		self.dataGridPredictedValues = QtGui.QTableView()
+		self.dataGridPredictedValues.setModel(ArrayTableModel(QtCore.Qt.ItemIsEnabled | QtCore.Qt.ItemIsSelectable))
+		self.dataGridPredictedValues.setSelectionMode(QtGui.QAbstractItemView.SingleSelection)
+		self.dataGridPredictedValues.setSelectionBehavior(QtGui.QAbstractItemView.SelectRows)
+		self.dataGridPredictedValues.verticalHeader().setDefaultSectionSize(20)
+
+		# groupBoxEncoding1Layout
+		groupBoxEncoding1Layout = QtGui.QGridLayout()
+		groupBoxEncoding1Layout.addWidget(self.checkBoxEnableClassificationLearning, 0, 1)
+		groupBoxEncoding1Layout.addWidget(self.checkBoxEnableClassificationInference, 1, 1)
+		groupBoxEncoding1Layout.addWidget(self.labelCurrentValue, 2, 0)
+		groupBoxEncoding1Layout.addWidget(self.textBoxCurrentValue, 2, 1)
+		groupBoxEncoding1Layout.setRowStretch(3, 100)
+
+		# sliderStep
+		self.sliderStep = QtGui.QSlider()
+		self.sliderStep.setOrientation(QtCore.Qt.Horizontal)
+		self.sliderStep.setSingleStep(1)
+		self.sliderStep.setRange(1, maxFutureSteps)
+		self.sliderStep.valueChanged.connect(self.__sliderStep_ValueChanged)
+
+		# groupBoxEncoding2Layout
+		groupBoxEncoding2Layout = QtGui.QGridLayout()
+		groupBoxEncoding2Layout.addWidget(self.sliderStep, 0, 1)
+		groupBoxEncoding2Layout.addWidget(self.labelPredictedValue, 1, 0)
+		groupBoxEncoding2Layout.addWidget(self.dataGridPredictedValues, 1, 1)
+
+		# groupBoxEncodingLayout
+		groupBoxEncodingLayout = QtGui.QHBoxLayout()
+		groupBoxEncodingLayout.addLayout(groupBoxEncoding1Layout)
+		groupBoxEncodingLayout.addLayout(groupBoxEncoding2Layout)
+
+		# groupBoxEncoding
+		self.groupBoxEncoding = QtGui.QGroupBox()
+		self.groupBoxEncoding.setLayout(groupBoxEncodingLayout)
+		self.groupBoxEncoding.setTitle("Encoding")
 
 		# tabPageSensorLayout
-		self.tabPageSensorLayout = QtGui.QGridLayout()
-		self.tabPageSensorLayout.addWidget(self.labelSensorName, 0, 0)
-		self.tabPageSensorLayout.addWidget(self.textBoxSensorName, 0, 1)
-		self.tabPageSensorLayout.addWidget(self.labelCurrentValue, 1, 0)
-		self.tabPageSensorLayout.addWidget(self.textBoxCurrentValue, 1, 1)
-		self.tabPageSensorLayout.addWidget(self.labelPredictedValue, 2, 0)
-		self.tabPageSensorLayout.addWidget(self.textBoxPredictedValue, 2, 1)
-		self.tabPageSensorLayout.setRowStretch(3, 100)
-		self.tabPageSensorLayout.setColumnStretch(2, 100)
+		tabPageSensorLayout = QtGui.QGridLayout()
+		tabPageSensorLayout.addLayout(tabPageSensor1Layout, 0, 0)
+		tabPageSensorLayout.addWidget(self.groupBoxEncoding, 0, 1)
+		tabPageSensorLayout.setColumnStretch(2, 100)
 
 		# tabPageSensor
 		self.tabPageSensor = QtGui.QWidget()
-		self.tabPageSensor.setLayout(self.tabPageSensorLayout)
+		self.tabPageSensor.setLayout(tabPageSensorLayout)
 
 		# dataGridBits
 		self.dataGridBits = QtGui.QTableView()
@@ -107,11 +165,35 @@ class NodeInformationForm(QtGui.QWidget):
 		self.textBoxRegionName.setEnabled(False)
 		self.textBoxRegionName.setAlignment(QtCore.Qt.AlignLeft)
 
+		# labelRegionPrecisionRate
+		self.labelRegionPrecisionRate = QtGui.QLabel()
+		self.labelRegionPrecisionRate.setText("Precision Rate (%)")
+		self.labelRegionPrecisionRate.setAlignment(QtCore.Qt.AlignRight)
+
+		# textBoxRegionPrecisionRate
+		self.textBoxRegionPrecisionRate = QtGui.QLineEdit()
+		self.textBoxRegionPrecisionRate.setEnabled(False)
+		self.textBoxRegionPrecisionRate.setAlignment(QtCore.Qt.AlignRight)
+
+		# checkBoxEnableSpatialPooling
+		self.checkBoxEnableSpatialPooling = QtGui.QCheckBox()
+		self.checkBoxEnableSpatialPooling.setText("Enable Spatial Pooling")
+		self.checkBoxEnableSpatialPooling.toggled.connect(self.__checkBoxEnableSpatialPooling_Toggled)
+
+		# checkBoxEnableTemporalPooling
+		self.checkBoxEnableTemporalPooling = QtGui.QCheckBox()
+		self.checkBoxEnableTemporalPooling.setText("Enable Temporal Pooling")
+		self.checkBoxEnableTemporalPooling.toggled.connect(self.__checkBoxEnableTemporalPooling_Toggled)
+
 		# tabPageRegionsLayout
 		self.tabPageRegionsLayout = QtGui.QGridLayout()
 		self.tabPageRegionsLayout.addWidget(self.labelRegionName, 0, 0)
 		self.tabPageRegionsLayout.addWidget(self.textBoxRegionName, 0, 1)
-		self.tabPageRegionsLayout.setRowStretch(1, 100)
+		self.tabPageRegionsLayout.addWidget(self.labelRegionPrecisionRate, 1, 0)
+		self.tabPageRegionsLayout.addWidget(self.textBoxRegionPrecisionRate, 1, 1)
+		self.tabPageRegionsLayout.addWidget(self.checkBoxEnableSpatialPooling, 2, 1)
+		self.tabPageRegionsLayout.addWidget(self.checkBoxEnableTemporalPooling, 3, 1)
+		self.tabPageRegionsLayout.setRowStretch(4, 100)
 		self.tabPageRegionsLayout.setColumnStretch(2, 100)
 
 		# tabPageRegions
@@ -217,6 +299,15 @@ class NodeInformationForm(QtGui.QWidget):
 		self.setMinimumHeight(200)
 		self.setMaximumHeight(300)
 
+	def clearControls(self):
+		"""
+		Reset all controls.
+		"""
+
+		self.textBoxCurrentValue.setText("")
+		self.sliderStep.setEnabled(False)
+		self.dataGridPredictedValues.model().update([], [])
+
 	def refreshControls(self):
 		"""
 		Refresh controls for each time step.
@@ -226,41 +317,88 @@ class NodeInformationForm(QtGui.QWidget):
 
 		# Show information according to note type
 		if selectedNode != self.previousSelectedNode:
-			if self.previousSelectedNode == None or self.previousSelectedNode.type != selectedNode.type:
-				while True:
-					self.tabControlMain.removeTab(0)
-					if self.tabControlMain.count() == 0:
-						break
-				if selectedNode.type == NodeType.region:
-					self.textBoxRegionName.setText(selectedNode.name)
-					self.showTab(self.tabPageRegions, "Region")
-					self.showTab(self.tabPageColumns, "Columns")
-					self.dataGridColumns.clearSelection()
-				elif selectedNode.type == NodeType.sensor:
-					self.textBoxSensorName.setText(selectedNode.name)
-					self.showTab(self.tabPageSensor, "Sensor")
-					self.showTab(self.tabPageBits, "Bits")
-					self.dataGridBits.clearSelection()
-				self.tabControlMain.selectedIndex = 0
+			while True:
+				self.tabControlMain.removeTab(0)
+				if self.tabControlMain.count() == 0:
+					break
+			if selectedNode.type == NodeType.region:
+				self.selectedRegion = selectedNode
+
+				self.textBoxRegionName.setText(self.selectedRegion.name)
+				self.checkBoxEnableSpatialPooling.setChecked(self.selectedRegion.enableSpatialPooling)
+				self.checkBoxEnableTemporalPooling.setChecked(self.selectedRegion.enableTemporalPooling)
+				self.showTab(self.tabPageRegions, "Region")
+				self.showTab(self.tabPageColumns, "Columns")
+				self.dataGridColumns.clearSelection()
+			elif selectedNode.type == NodeType.sensor:
+				self.selectedSensor = selectedNode
+
+				self.textBoxSensorName.setText(self.selectedSensor.name)
+				self.showTab(self.tabPageSensor, "Sensor")
+				self.showTab(self.tabPageBits, "Bits")
+				self.dataGridBits.clearSelection()
+				if self.selectedSensor.inputFormat == InputFormat.raw:
+					self.groupBoxEncoding.setVisible(True)
+					if self.selectedSensor.predictionsMethod == PredictionsMethod.classification:
+						self.checkBoxEnableClassificationLearning.setVisible(True)
+						self.checkBoxEnableClassificationLearning.setChecked(self.selectedSensor.enableClassificationLearning)
+						self.checkBoxEnableClassificationInference.setVisible(True)
+						self.checkBoxEnableClassificationInference.setChecked(self.selectedSensor.enableClassificationInference)
+					else:
+						self.checkBoxEnableClassificationLearning.setVisible(False)
+						self.checkBoxEnableClassificationInference.setVisible(False)
+				else:
+					self.groupBoxEncoding.setVisible(False)
+			self.tabControlMain.selectedIndex = 0
+
 			self.previousSelectedNode = selectedNode
 
-		if selectedNode.type == NodeType.region:
-			self.selectedRegion = selectedNode
+		if Global.simulationInitialized:
+			if selectedNode.type == NodeType.region:
+				self.textBoxRegionPrecisionRate.setText("{0:.3f}".format(self.selectedRegion.statsPrecisionRate))
 
-			# Bind the columns from this region
-			header, data = self.getColumnsData(self.selectedRegion)
-			self.dataGridColumns.model().update(header, data)
-			self.dataGridColumns.resizeColumnsToContents()
+				# Bind the columns from this region
+				header, data = self.getColumnsData(self.selectedRegion)
+				self.dataGridColumns.model().update(header, data)
+				self.dataGridColumns.resizeColumnsToContents()
 
-		elif selectedNode.type == NodeType.sensor:
-			self.selectedSensor = selectedNode
+			elif selectedNode.type == NodeType.sensor:
+				self.textBoxSensorPrecisionRate.setText("{0:.3f}".format(self.selectedSensor.statsPrecisionRate))
 
-			"""TODO:# Update node controls"""
+				# Bind the bits from this sensor
+				header, data = self.getBitsData(self.selectedSensor)
+				self.dataGridBits.model().update(header, data)
+				self.dataGridBits.resizeColumnsToContents()
 
-			# Bind the bits from this sensor
-			header, data = self.getBitsData(self.selectedSensor)
-			self.dataGridBits.model().update(header, data)
-			self.dataGridBits.resizeColumnsToContents()
+				if self.selectedSensor.inputFormat == InputFormat.raw:
+					currValue = self.formatValue(self.selectedSensor.currentValue[Global.selStep])
+					self.textBoxCurrentValue.setText(currValue)
+					self.sliderStep.setEnabled(True)
+					self.sliderStep.setValue(self.sliderStep.minimum())
+					self.updatePredictedValuesGrid()
+					if self.selectedSensor.predictionsMethod == PredictionsMethod.classification:
+						self.sliderStep.setEnabled(True)
+					else:
+						self.sliderStep.setEnabled(False)
+
+	def formatValue(self, value):
+		formattedValue = None
+
+		if self.selectedSensor.inputRawDataType == InputRawDataType.boolean:
+			if value == 0:
+				formattedValue = "False"
+			else:
+				formattedValue = "True"
+		elif self.selectedSensor.inputRawDataType == InputRawDataType.integer:
+			formattedValue = "{0}".format(value)
+		elif self.selectedSensor.inputRawDataType == InputRawDataType.decimal:
+			formattedValue = "{0:.3f}".format(value)
+		elif self.selectedSensor.inputRawDataType == InputRawDataType.dateTime:
+			formattedValue = value.strftime("%m/%d/%y %H:%M")
+		else:
+			formattedValue = value
+
+		return formattedValue
 
 	def getBitsData(self, selectedSensor):
 		header = ['Pos (x,y)', 'Was Predicted', 'Is Active', 'Activation Rate', 'Precision Rate']
@@ -275,6 +413,32 @@ class NodeInformationForm(QtGui.QWidget):
 
 		return header, data
 
+	def updatePredictedValuesGrid(self):
+		step = self.sliderStep.value()
+		header, data = self.getPredictedValuesData(step)
+		self.dataGridPredictedValues.model().update(header, data)
+		self.dataGridPredictedValues.resizeColumnsToContents()
+
+	def getPredictedValuesData(self, futureStep):
+		header = []
+		if self.selectedSensor.predictionsMethod == PredictionsMethod.reconstruction:
+			header = ['Value']
+		elif self.selectedSensor.predictionsMethod == PredictionsMethod.classification:
+			header = ['Value', 'Probability']
+
+		predictions = self.selectedSensor.predictedValues[Global.selStep][futureStep]
+		data = []
+		for predictedValue in predictions:
+			if self.selectedSensor.predictionsMethod == PredictionsMethod.reconstruction:
+				value = predictedValue[1]
+				data.append([value])
+			elif self.selectedSensor.predictionsMethod == PredictionsMethod.classification:
+				value = self.formatValue(predictedValue[0])
+				probability = "{0:.3f}".format(predictedValue[1] * 100)
+				data.append([value, probability])
+
+		return header, data
+
 	def getColumnsData(self, selectedRegion):
 		header = ['Pos (x,y)', 'Was Predicted', 'Is Active', 'Activation Rate', 'Precision Rate']
 		data = []
@@ -353,6 +517,21 @@ class NodeInformationForm(QtGui.QWidget):
 		self.Parent = None
 		event.Cancel = True
 
+	def __sliderStep_ValueChanged(self, value):
+		self.updatePredictedValuesGrid()
+
+	def __checkBoxEnableSpatialPooling_Toggled(self, event):
+		self.selectedRegion.enableSpatialPooling = self.checkBoxEnableSpatialPooling.isChecked()
+
+	def __checkBoxEnableTemporalPooling_Toggled(self, event):
+		self.selectedRegion.enableTemporalPooling = self.checkBoxEnableTemporalPooling.isChecked()
+
+	def __checkBoxEnableClassificationLearning_Toggled(self, event):
+		self.selectedSensor.enableClassificationLearning = self.checkBoxEnableClassificationLearning.isChecked()
+
+	def __checkBoxEnableClassificationInference_Toggled(self, event):
+		self.selectedSensor.enableClassificationInference = self.checkBoxEnableClassificationInference.isChecked()
+
 	def __dataGridColumns_SelectionChanged(self, event):
 		if self.selectedColumn != None:
 			self.selectedColumn.segment.tree3d_selected = False
